# OpenFisca US

[![codecov](https://codecov.io/gh/PolicyEngine/openfisca-us/branch/master/graph/badge.svg?token=BLoCjCf5Qr)](https://codecov.io/gh/PolicyEngine/openfisca-us)

OpenFisca US is a microsimulation model of the US state and federal tax and benefit system.
It is built by [PolicyEngine](https://policyengine.org) and supported in part by the [Center for Growth and Opportunity](https://thecgo.org).

To install, run `pip install git+https://github.com/policyengine/openfisca-us`.

To contribute, please see the [wiki](https://github.com/PolicyEngine/openfisca-us/wiki).

See our documentation with interactive notebooks at [openfisca.us](https://openfisca.us).
